Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(309)

Unified Diff: sdk/lib/io/platform.dart

Issue 1417013011: Report iOS as iOS rather than OS X. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: sync Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/os_macos.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/platform.dart
diff --git a/sdk/lib/io/platform.dart b/sdk/lib/io/platform.dart
index 56ddea0193b0df98b43e703e0c98828f4eb1e696..c9e1cc66d6d084212d356c0be7a099731327d3ce 100644
--- a/sdk/lib/io/platform.dart
+++ b/sdk/lib/io/platform.dart
@@ -84,7 +84,7 @@ class Platform {
static String get pathSeparator => _pathSeparator;
/**
* Get a string (`linux`, `macos`, `windows` or `android`)
* representing the operating system.
*/
static String get operatingSystem => _operatingSystem;
@@ -115,6 +115,11 @@ class Platform {
static final bool isAndroid = (_operatingSystem == "android");
/**
+ * Returns true if the operating system is iOS.
+ */
+ static final bool isiOS = (_operatingSystem == "ios");
+
+ /**
* Get the environment for this process.
*
* The returned environment is an unmodifiable map which content is
@@ -84,7 +84,7 @@ class Platform {
static String get pathSeparator => _pathSeparator;
/**
- * Get a string (`linux`, `macos`, `windows` or `android`)
+ * Get a string (`linux`, `macos`, `windows`, `android`, or `ios`)
* representing the operating system.
*/
« no previous file with comments | « runtime/vm/os_macos.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698